@@ -1,7 +1,8 @@
 /* Totem Basic Plugin
  *
- * Copyright (C) 2004 Bastien Nocera <hadess@hadess.net>
- * Copyright (C) 2002 David A. Schleef <ds@schleef.org>
+ * Copyright © 2004 Bastien Nocera <hadess@hadess.net>
+ * Copyright © 2002 David A. Schleef <ds@schleef.org>
+ * Copyright © 2008 Christian Persch
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -17,38 +18,31 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301  USA.
- *
- * $Id: totemBasicPlugin.h 5373 2008-04-24 15:28:08Z hadess $
  */
 
 #ifndef __BASIC_PLUGIN_H__
 #define __BASIC_PLUGIN_H__
 
-#include <nsIClassInfo.h>
+#include "totemNPClass.h"
+#include "totemNPObject.h"
 
-#include "totemIBasicPlayer.h"
-#include "totemPlugin.h"
-
-class totemScriptablePlugin : public totemIBasicPlayer,
-			      public nsIClassInfo
+class totemBasicPlayer : public totemNPObject
 {
   public:
-    NS_DECL_ISUPPORTS
-    NS_DECL_TOTEMIBASICPLAYER
-    NS_DECL_NSICLASSINFO
+    totemBasicPlayer (NPP);
+    virtual ~totemBasicPlayer ();
 
-    totemScriptablePlugin (totemPlugin *aPlugin);
-
-    PRBool IsValid () { return mPlugin != nsnull; }
-    void SetPlugin (totemPlugin *aPlugin) { mPlugin = aPlugin; }
-
-    static char *PluginDescription ();
-    static char *PluginLongDescription();
-    static void PluginMimeTypes (const totemPluginMimeEntry **, PRUint32 *);
   private:
-    ~totemScriptablePlugin ();
+  
+    enum Methods {
+      ePlay,
+      eRewind,
+      eStop
+    };
 
-    totemPlugin *mPlugin;
+    virtual bool InvokeByIndex (int aIndex, const NPVariant *argv, uint32_t argc, NPVariant *_result);
 };
 
+TOTEM_DEFINE_NPCLASS (totemBasicPlayer);
+
 #endif /* __BASIC_PLUGIN_H__ */
