@@ -88,7 +88,7 @@
 
 static const totemPluginMimeEntry kMimeTypes[] = {
 #if defined(TOTEM_BASIC_PLUGIN)
-  { "application/x-ogg","ogg",NULL },
+  { "application/x-ogg","ogg","application/ogg" },
   { "application/ogg", "ogg", NULL },
   { "audio/ogg", "oga", NULL },
   { "audio/x-ogg", "ogg", NULL },
@@ -103,7 +103,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
   { "audio/mpeg", "mp3", NULL },
   { "application/x-nsv-vp3-mp3", "nsv", "video/x-nsv" },
   { "video/flv", "flv", "application/x-flash-video" },
-  { "application/x-totem-plugin", "", "application/octet-stream" },
+  { "application/x-totem-plugin", "", "Totem Multimedia plugin" },
 #elif defined(TOTEM_GMP_PLUGIN)
   { "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo" },
   { "video/x-ms-asf-plugin", "asf, wmv", "video/x-ms-asf" },
@@ -115,6 +115,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
   { "video/x-ms-wm", "wmv", "video/x-ms-wmv" },
   { "video/x-ms-wmp", "wmv", "video/x-ms-wmv" },
   { "application/x-ms-wms", "wms", "video/x-ms-wmv" },
+  { "application/x-ms-wmp", "wmp", "video/x-ms-wmv" },
   { "application/asx", "asx", "audio/x-ms-asx" },
   { "audio/x-ms-wma", "wma", NULL }
 #elif defined(TOTEM_COMPLEX_PLUGIN)
@@ -128,9 +129,9 @@ static const totemPluginMimeEntry kMimeTypes[] = {
 #elif defined(TOTEM_MULLY_PLUGIN)
   { "video/divx", "divx", "video/x-msvideo" },
 #elif defined(TOTEM_CONE_PLUGIN)
-  { "application/x-vlc-plugin", "", "application/octet-stream" },
-  { "application/vlc", "", "application/octet-stream" },
-  { "video/x-google-vlc-plugin", "", "application/octet-stream" },
+  { "application/x-vlc-plugin", "", "VLC Multimedia Plugin" },
+  { "application/vlc", "", "VLC Multimedia Plugin" },
+  { "video/x-google-vlc-plugin", "", "VLC Multimedia Plugin" },
 #else
 #error Unknown plugin type
 #endif
@@ -1055,6 +1056,13 @@ totemPlugin::RequestStream (bool aForceViewer)
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Playable;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_Waiting;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 }
 
 void
@@ -1082,6 +1090,13 @@ totemPlugin::UnsetStream ()
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Waiting;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_MediaEnded;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 }
 
 /* Callbacks */
@@ -1165,6 +1180,26 @@ totemPlugin::TickCallback (DBusGProxy *proxy,
 
 	plugin->mTime = aTime;
 	plugin->mDuration = aDuration;
+
+#ifdef TOTEM_GMP_PLUGIN
+        if (!plugin->mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = plugin->mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+                switch (plugin->mState) {
+		case TOTEM_STATE_PLAYING:
+			scriptable->mPluginState = totemGMPPlayer::eState_Playing;
+			break;
+		case TOTEM_STATE_PAUSED:
+			scriptable->mPluginState = totemGMPPlayer::eState_Paused;
+			break;
+		case TOTEM_STATE_STOPPED:
+			scriptable->mPluginState = totemGMPPlayer::eState_Stopped;
+			break;
+		default:
+			scriptable->mPluginState = totemGMPPlayer::eState_Undefined;
+		}
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 }
 
 /* static */ void
@@ -1269,6 +1304,13 @@ totemPlugin::ViewerOpenStreamCallback (DBusGProxy *aProxy,
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Playable;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!plugin->mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = plugin->mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_Waiting;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 }
 
 /* static */ void
@@ -1300,6 +1342,13 @@ totemPlugin::ViewerOpenURICallback (DBusGProxy *aProxy,
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Playable;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!plugin->mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = plugin->mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_Ready;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 
 	/* FIXME this isn't the best way... */
 	if (plugin->mAutoPlay) {
@@ -2266,6 +2315,13 @@ totemPlugin::NewStream (NPMIMEType type,
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Loading;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_Buffering;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 
 	mStream = stream;
 
@@ -2482,6 +2538,13 @@ totemPlugin::StreamAsFile (NPStream *stream,
 		scriptable->mPluginState = totemNarrowSpacePlayer::eState_Complete;
 	}
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
+#ifdef TOTEM_GMP_PLUGIN
+        if (!mNPObjects[ePluginScriptable].IsNull ()) {
+                NPObject *object = mNPObjects[ePluginScriptable];
+                totemGMPPlayer *scriptable = static_cast<totemGMPPlayer*>(object);
+		scriptable->mPluginState = totemGMPPlayer::eState_Ready;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
 }
     
 void
