@@ -37,6 +37,31 @@ on_eos_event (GtkWidget *widget, gpointer user_data)
 	bacon_video_widget_play (BACON_VIDEO_WIDGET (bvw), NULL);
 }
 
+static void
+on_got_metadata (BaconVideoWidget *bvw, gpointer data)
+{
+	GValue value = { 0, };
+	char *title, *artist;
+
+	bacon_video_widget_get_metadata (BACON_VIDEO_WIDGET (bvw),
+			BVW_INFO_TITLE, &value);
+	title = g_value_dup_string (&value);
+	g_value_unset (&value);
+
+	bacon_video_widget_get_metadata (BACON_VIDEO_WIDGET (bvw),
+			BVW_INFO_ARTIST, &value);
+	artist = g_value_dup_string (&value);
+	g_value_unset (&value);
+
+	g_message ("Got metadata: title = %s artist = %s", title, artist);
+}
+
+static void
+on_title_changed (BaconVideoWidget *bvw, const char *title, gpointer data)
+{
+	g_message ("Got title change signal: %s", title);
+}
+
 static void
 error_cb (GtkWidget *bvw, const char *message,
 		gboolean playback_stopped, gboolean fatal)
@@ -72,7 +97,9 @@ int main
 	bvw = bacon_video_widget_new (width, height,
 			BVW_USE_TYPE_VIDEO, NULL);
 
-	g_signal_connect (G_OBJECT (bvw),"eos",G_CALLBACK (on_eos_event),NULL);
+	g_signal_connect (G_OBJECT (bvw), "eos", G_CALLBACK (on_eos_event), NULL);
+	g_signal_connect (G_OBJECT (bvw), "got-metadata", G_CALLBACK (on_got_metadata), NULL);
+	g_signal_connect (G_OBJECT (bvw), "title-change", G_CALLBACK (on_title_changed), NULL);
 	g_signal_connect (G_OBJECT (bvw), "got-redirect", G_CALLBACK (on_redirect), NULL);
 	g_signal_connect (G_OBJECT (bvw), "error", G_CALLBACK (error_cb), NULL);
 
