@@ -426,9 +426,12 @@ static gboolean
 has_audio (BaconVideoWidget *bvw)
 {
 	GValue value = { 0, };
+	gboolean retval;
 
 	bacon_video_widget_get_metadata (bvw, BVW_INFO_HAS_VIDEO, &value);
-	return g_value_get_boolean (&value);
+	retval = g_value_get_boolean (&value);
+	g_value_unset (&value);
+	return retval;
 }
 
 static void
@@ -439,7 +442,8 @@ on_got_metadata_event (BaconVideoWidget *bvw, callback_data *data)
 
 	PROGRESS_DEBUG("Got metadata, checking if we have a cover");
 	bacon_video_widget_get_metadata (bvw, BVW_INFO_COVER, &value);
-	pixbuf = g_value_get_object (&value);
+	pixbuf = g_value_dup_object (&value);
+	g_value_unset (&value);
 
 	if (pixbuf) {
 		PROGRESS_DEBUG("Saving cover image");
@@ -464,9 +468,7 @@ static const GOptionEntry entries[] = {
 	{ "no-limit", 'l', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &time_limit, "Don't limit the thumbnailing time to 30 seconds", NULL },
 	{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose, "Output debug information", NULL },
 	{ "time", 't', 0, G_OPTION_ARG_INT64, &second_index, "Choose this time (in seconds) as the thumbnail", NULL },
-#ifndef THUMB_DEBUG
 	{"g-fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &g_fatal_warnings, "Make all warnings fatal", NULL},
-#endif /* THUMB_DEBUG */
  	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, NULL, "[FILE...]" },
 	{ NULL }
 };
